From 86c663ae22845a075cea9216a4a5e053e6c16c04 Mon Sep 17 00:00:00 2001
From: Andrew Schwartzmeyer <andrew@schwartzmeyer.com>
Date: Sun, 31 May 2020 11:56:01 -0700
Subject: [PATCH] Fix prompts when using fido-mode

When fido-mode is enabled, you need to use M-j to end the selection, not
RET. This is similar to ido-mode, which was already special-cased for
multi-occur and multi-isearch-buffers.
---
 lisp/misearch.el | 11 ++++++++---
 lisp/replace.el  | 11 ++++++++---
 2 files changed, 16 insertions(+), 6 deletions(-)

diff --git a/lisp/misearch.el b/lisp/misearch.el
index 958c10a1b..69ba77fea 100644
--- a/lisp/misearch.el
+++ b/lisp/misearch.el
@@ -237,9 +237,14 @@ set in `multi-isearch-buffers' or `multi-isearch-buffers-regexp'."
 	 (ido-ignore-item-temp-list bufs))
     (while (not (string-equal
 		 (setq buf (read-buffer
-			    (if (eq read-buffer-function #'ido-read-buffer)
-				"Next buffer to search (C-j to end): "
-			      "Next buffer to search (RET to end): ")
+			    (concat
+                             "Next buffer to search "
+                             (cond
+                              ((eq read-buffer-function #'ido-read-buffer)
+                               "(C-j to end): ")
+                              ((bound-and-true-p fido-mode)
+                               "(M-j to end): ")
+                              (t "(RET to end): ")))
 			    nil t))
 		 ""))
       (add-to-list 'bufs buf)
diff --git a/lisp/replace.el b/lisp/replace.el
index 69092c16f..8cd92d894 100644
--- a/lisp/replace.el
+++ b/lisp/replace.el
@@ -1585,9 +1585,14 @@ See also `multi-occur-in-matching-buffers'."
 	   (ido-ignore-item-temp-list bufs))
       (while (not (string-equal
 		   (setq buf (read-buffer
-			      (if (eq read-buffer-function #'ido-read-buffer)
-				  "Next buffer to search (C-j to end): "
-				"Next buffer to search (RET to end): ")
+			      (concat
+                               "Next buffer to search "
+                               (cond
+                                ((eq read-buffer-function #'ido-read-buffer)
+                                 "(C-j to end): ")
+                                ((bound-and-true-p fido-mode)
+                                 "(M-j to end): ")
+                                (t "(RET to end): ")))
 			      nil t))
 		   ""))
 	(cl-pushnew buf bufs)
-- 
2.26.0

